==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserSchemaAttributeMaster.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserSchemaAttributeMasterPriority;
import com.okta.sdk.resource.model.UserSchemaAttributeMasterType;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserSchemaAttributeMaster
 */
@JsonPropertyOrder({ UserSchemaAttributeMaster.JSON_PROPERTY_PRIORITY, UserSchemaAttributeMaster.JSON_PROPERTY_TYPE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class UserSchemaAttributeMaster implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PRIORITY = "priority";
    private List<UserSchemaAttributeMasterPriority> priority = null;

    public static final String JSON_PROPERTY_TYPE = "type";
    private UserSchemaAttributeMasterType type;

    public UserSchemaAttributeMaster() {
    }

    public UserSchemaAttributeMaster priority(List<UserSchemaAttributeMasterPriority> priority) {

        this.priority = priority;
        return this;
    }

    public UserSchemaAttributeMaster addpriorityItem(UserSchemaAttributeMasterPriority priorityItem) {
        if (this.priority == null) {
            this.priority = new ArrayList<>();
        }
        this.priority.add(priorityItem);
        return this;
    }

    /**
     * Get priority
     *
     * @return priority
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PRIORITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<UserSchemaAttributeMasterPriority> getPriority() {
        return priority;
    }

    @JsonProperty(JSON_PROPERTY_PRIORITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPriority(List<UserSchemaAttributeMasterPriority> priority) {
        this.priority = priority;
    }

    public UserSchemaAttributeMaster type(UserSchemaAttributeMasterType type) {

        this.type = type;
        return this;
    }

    /**
     * Get type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserSchemaAttributeMasterType getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(UserSchemaAttributeMasterType type) {
        this.type = type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserSchemaAttributeMaster userSchemaAttributeMaster = (UserSchemaAttributeMaster) o;
        return Objects.equals(this.priority, userSchemaAttributeMaster.priority)
                && Objects.equals(this.type, userSchemaAttributeMaster.type);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(priority, type);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserSchemaAttributeMaster {\n");
        sb.append("    priority: ").append(toIndentedString(priority)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserSchemaAttributeMaster.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserSchemaAttributeMasterPriority;
import com.okta.sdk.resource.model.UserSchemaAttributeMasterType;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserSchemaAttributeMaster
 */
@JsonPropertyOrder({ UserSchemaAttributeMaster.JSON_PROPERTY_PRIORITY, UserSchemaAttributeMaster.JSON_PROPERTY_TYPE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UserSchemaAttributeMaster implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PRIORITY = "priority";
    private List<UserSchemaAttributeMasterPriority> priority = null;

    public static final String JSON_PROPERTY_TYPE = "type";
    private UserSchemaAttributeMasterType type;

    public UserSchemaAttributeMaster() {
    }

    public UserSchemaAttributeMaster priority(List<UserSchemaAttributeMasterPriority> priority) {

        this.priority = priority;
        return this;
    }

    public UserSchemaAttributeMaster addpriorityItem(UserSchemaAttributeMasterPriority priorityItem) {
        if (this.priority == null) {
            this.priority = new ArrayList<>();
        }
        this.priority.add(priorityItem);
        return this;
    }

    /**
     * Get priority
     *
     * @return priority
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PRIORITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<UserSchemaAttributeMasterPriority> getPriority() {
        return priority;
    }

    @JsonProperty(JSON_PROPERTY_PRIORITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPriority(List<UserSchemaAttributeMasterPriority> priority) {
        this.priority = priority;
    }

    public UserSchemaAttributeMaster type(UserSchemaAttributeMasterType type) {

        this.type = type;
        return this;
    }

    /**
     * Get type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserSchemaAttributeMasterType getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(UserSchemaAttributeMasterType type) {
        this.type = type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserSchemaAttributeMaster userSchemaAttributeMaster = (UserSchemaAttributeMaster) o;
        return Objects.equals(this.priority, userSchemaAttributeMaster.priority)
                && Objects.equals(this.type, userSchemaAttributeMaster.type);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(priority, type);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserSchemaAttributeMaster {\n");
        sb.append("    priority: ").append(toIndentedString(priority)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
